HEIDI:
Previously on Project Runway...
Move those hips.
Shake your little booty.
[laughter, cheering]
Designers,
we want your next look
to be inspired by dance,
movement and innovation.
MARGARITA:
Innovation.
I think it could be really fun.
-[Shawn cries out]
-CLAIRE: Shawny.
-[cries out]
-Ooh!
-Aah.
-[chuckles]
This looks stunning.
I'm inspired.
-I can't wait to see it.
-[chuckles]
It is super tight.
[shrieks]
HEIDI:
Designers, I have to say,
this was
a fantastic runway show.
Brandon, it is fabulous.
It made me want to dance.
-I love this.
-Congratulations.
You are the winner
of this challenge.
Kudzanai, you threw everything
into your design today,
and it just did not work.
I'm sorry, you're out.
♪ ♪
♪ ♪
[car horn honks]
[designers groaning, exclaiming]
Oh, my God.
-Hello.
-Hi.
Please, no.
Hi, guys.
DESIGNERS:
Hello.
It seems
like you were just here.
Oh, wait, you were.
[laughter]
Designers, we asked you to come
down to the runway immediately
because you have
somewhere to be.
-Oh?
-Oh, my gosh.
But first, let's get
to your next challenge.
This challenge
is very important to me.
You'll be creating
a sleepwear look
for my Heidi Klum Intimates
sleepwear line.
-Ooh.
-Oh, wow.
You can create
any type of sleepwear.
The biggest rule:
make it fashionable.
You are also going to be
creating your own textile.
Yes.
HEIDI:
By hand.
This is what
I've been waiting for.
And there's a lot
on the line for you.
-Okay.
-The winner of this challenge
will have their entire look
reproduced and sold
as part of my Heidi Klum
Intimates sleepwear collection.
-[designers exclaim]
-Yay!
Okay, I need to win.
It's literally
Heidi Klum Intimates.
I mean, what better way
to kind of get your name
out there?
Now...
for where we are sending you
for inspiration.
We thought it would be fun
for you to have a slumber party
in one of New York's
most iconic locations.
The Empire State Building!
[designers cheer]
That's insane.
AARON:
That's, like, super exciting.
It's, like, a crazy thing.
No one's ever done it before.
You'll need a key,
and I have it.
[designers cheer, laugh]
You're sleeping on top
of the Empire State Building.
Claire, are you nervous,
or are you excited?
That building is very tall.
-Well, you're going
all the way up. -Yep.
-This is gonna be horrible.
[laughs] -Horrible. [laughs]
So, there is a backpack
for each of you.
HEIDI:
Come and get it.
Inside you'll find pajamas
and your sketching materials.
-Ooh! Me! -There's me!
-That's mine! -Ooh!
And your models have been
assigned to each of you.
You'll find their card
in your sketchbook.
Brandon, you won
the last challenge,
which means you have immunity
and you cannot be eliminated.
-Sounds good. -And, Brandon,
I'm giving you the key.
There you go.
It's a big responsibility.
-[designers cheer]
-[Heidi laughs]
Brandon Kee with the key.
I can't wait to get up there
and have
a slumber party
at the Empire State Building.
I wish you all good luck,
and sleep well tonight
under the stars
and bright lights
of New York City!
[designers cheer]
And I will see you
in the morning.
-Have fun. -Off we go.
-DESIGNERS: Bye.
♪ ♪
[designers exclaim]
Oh, my gosh.
Amazing.
AARON: Yeah, the ceiling's
beautiful, y'all.
BRANDON:
Let's go to the top.
♪ ♪
BATANI:
The ground is beautiful.
The walls are beautiful.
SAMANTHA:
I love art deco.
It's so elegant.
DEYONTÉ:
There's inspiration
everywhere you look.
-This way, this way.
-Let's do it.
Which floor?
DEYONTÉ:
SHAWN: Are you, like,
hugging the wall, Claire,
-like...?
-I'm... no, I am not that bad.
-Excited.
-[designers scream, laugh]
-Oh, my God.
-Check it out.
-Check it out. Check it out.
-[shrieks] -Wow.
DEYONTÉ:
I'm on the top of the world!
I'll never forget this sight.
Ever.
AYANA:
Oh, I have Christina.
Well, she's a cutie.
I have Janine.
Nice, nice.
I got Jazzmine.
Okay, Jazzmine,
let's work this out.
I'm a bit nervous.
I've never done
sleepwear before.
I hope it don't look
too much like a dress.
Here's something that
I have to try to figure out
and please Heidi.
MICHAEL:
I instantly get inspired
by the Chrysler Building.
With the angles
and the art deco,
I think of
a Harlem Renaissance dress.
Harlem Renaissance
was more about sexuality
and fluidity,
so I think that is so fitting
for this challenge.
All right, naptime, everybody.
-This is unreal.
-Like, can you believe this?
We are sleeping
on the top of the world.
Once in a lifetime.
SAMANTHA:
I am... in disbelief
that I'm experiencing
something like this.
This was just for us,
and I feel
like that's really special.
ALL:
Good night, New York City!
[whooping]
[car horns honk]
Designers, good morning.
-No!
-Rise and shine.
We have a busy day ahead of us,
and I have breakfast sandwiches
for everyone.
-Yay.
-Yay!
MARGARITA:
Tim's just standing there
with a bag of sandwiches
in the most beautiful
double-breasted suit
with, like,
four-and-a-half-inch lapels.
I'm like,
"How does this man do it?"
All right, designers.
You ready to head back
to the workroom?
Yeah.
All right, everyone. Off we go.
♪ ♪
[car horn honks]
[indistinct chatter]
-Hi, Tim. -Hey, Tim.
-Hi, everyone.
You have 11 hours
in the workroom.
Heidi and I will be in
at 11:30, all right?
Your models will be in at 5:30.
Your textiles,
all selected by Heidi,
are over here.
We have plenty
of materials over here
for you to make your prints.
I will see you later with Heidi.
-All right. -Have fun
with this challenge, all right?
-All right.
-See you later. Thank you.
Bye.
♪ ♪
-Oh. Wait, Ow! Jesus.
-Whoa, guys, chill.
SAMANTHA:
Guys, chill.
Chill, chill, chill.
#Drama.
♪ ♪
SAMANTHA: This is a one-day
challenge, and they've given us
a lot of dyes and paints
to create
our own textiles using
different hand techniques.
You look like you know
what you're doing over there.
I'm making a bunch of tests.
KENYA: Well, I kind of jumped
right on in, so if this
don't work, I'm done after that!
MARGARITA: You're gonna
make it work. [laughs]
♪ ♪
-It's a different shade of
purple. -Okay, I'm just saying.
DEYONTÉ: You both know
what you're doing already?
I'm gonna do a long jumpsuit.
The first thing I want to do is
to generate this
art deco-esque print
that I want to put all over
the entire jumpsuit.
Ay, ay, ay.
Okay, we're not doing that.
It's only, you know, a few hours
till Heidi Klum's critique,
so I'm, like, freaking out.
Hopefully I'll be able
to show them
something much better this time,
and, um, we'll see.
I'm sweating today.
Aah! There's the snagging.
This fabric sucks so bad.
I think all the designers
right now are just
freaking out,
because we all know
how specific Heidi can be, and
since the textile
is very specific,
if she hates it,
you could be going home.
MARGARITA: They're coming
in, like, one hour.
DEYONTÉ:
I know.
HEIDI:
Coming up on Project Runway...
Something's wrong.
-TIM: I see a menstrual cycle.
-[gasps]
Less chatting, more working.
You're looking at me like...
[chokes]
TIM:
It's a "make it work" time.
There's some design here.
-Deco Cleopatra.
-It's beautiful.
The shape is so... nothing.
Thank goodness
you're wearing underpants.
Show me,
what is sexy about this?
♪ ♪
SAMANTHA: This week's challenge
is to create a look
inspired by the Empire
State Building for Heidi's
Intimates sleepwear collection.
AMY: We need to create
our own textiles through either
dying or painting or
some sort of
hands-done technique.
Would anyone like hash browns?
MARGARITA:
The prize for the challenge
is that she will
mass-produce and manufacture
the winning garment.
Oh, yeah.
Finally getting somewhere.
Ah, yeah.
-I have a question for you.
-What's your question, boo-boo?
-What do you think of this
color? -That might be kind of
-eh.
-Nasty?
-Do you like the size?
-Yeah.
Am I your Tim Gunn? Maybe.
-Can she be my Tim Gunn? No.
-No. No.
-Tim Gunn is Tim Gunn.
-Of course.
[gasps] This is the first time
I've ever painted fabric.
My idea for creating
my textile... oh, man.
It looks like a craft project,
so I pretty much scratched
everything.
-Good morning! -DESIGNERS:
Good morning! -Look who I have!
Are you ready for Heidi
to check in with you?
-Yes, indeed.
-Let's have a look.
-Hi, Shawn.
-Hi there.
Hi. Tim said he's surprised
that you even have anything
on the dress form.
-I'm pleased.
-I'm a bit slower than others.
I'm a slower sewer,
I'm indecisive.
Or are you a little bit over
there chatty, chatty, chatty
-with your fellow designers?
-I...
'Cause you two love to chat.
-Oh, we certainly do.
-Less chatting, more working.
SHAWN: I was wanting to do
a full-body jumpsuit.
HEIDI:
And how do you get
in and out of it? Because,
in the middle of the night,
you have to run to the toilet
all the time,
and you don't want buttons
where you're like...
-Right, right.
-SHAWN: Or a zip, or...
Can't get out.
Gonna pee in my pants.
SHAWN: I don't disagree
with what she's saying,
but my game plan is
to really deliver
something that is
-Thank you.
-Thank you, Shawn. -Thank you.
-Hello! -AYANA: For this
challenge, I'm not doing
-a "modest" look.
-Why not?
We don't wear all this inside.
Inside, we prefer
to wear a little less.
HEIDI:
Wow! So, she's basically
see-through everywhere.
Just the boobies are covered.
-[laughing]
-Check you out!
[Tim laughs]
I just want to do something soft
and flowy and sexy.
-What do you wear to bed?
-[laughing]
Is that a weird question?
I don't know.
So I'm making
sort of a kimono robe.
This is also very pretty.
Now, would you see this
on the bottom?
TIM: I don't know.
I see a menstrual cycle.
[gasps]
You do?
-Yeah.
-Bye.
Hi, Michael.
-Hello. -What's happening here
with these straps?
-This is all gonna be straps.
-So, you have to also think
-about getting into it, right,
so that it's not like... -Yeah.
-a cobweb and you're,
like, stuck... -Yeah.
-and it's, like, really tricky
to get into it. -Believe me.
I've made many of those pieces
that are just, like,
you need a map.
HEIDI: Also, I think
a little bit longer
is a little bit more elegant.
You know, I wanted it to work
not just in the bedroom.
-Yeah.
-Um, but make a really
-fashionable piece.
-Yeah.
I've been safe this whole time,
and it's time
for me to be on top.
-HEIDI: Thank you, Michael.
-TIM: Thank you.
-Thank you, guys.
-HEIDI: Bye.
So I want to do appliqué,
so I'm playing
around with kind of some dry
brush or stamp techniques.
HEIDI: I don't know.
This is a bit, like, you know?
-tr*mp stamp? -Yeah, you just
bedazzled a little tr*mp stamp
here, a little bit on the side.
Be a little bit
-more gutsy, because
this is good. -Too nasty?
-Tie it in somehow.
-TIM: Yeah.
KENYA:
Listening to
some of the other critiques,
I'm terrified
going into my critique.
It's...
It's looking pretty ugly.
And how is it going over here?
'Cause I was thinking,
two-tone romper,
drawstring robe, back out.
Does this read sleepwear to you?
-Potentially.
-If it has
-an ease to it.
-If it has an ease.
HEIDI: You want to be
in the bed, you got to move.
It's got to be easy.
[laughs]
You're looking at me like...
[chokes]
KENYA:
Lord
have mer... cy.
HEIDI:
Coming up on Project Runway...
-I don't like this.
-Oh, my God. Oh, my God.
DEYONTÉ: I'm just gonna have
to freestyle the bottom.
I'm freaking out a little bit.
-Ooh! Aah! -Freakin' sucks.
-Damn! Everyone had a moment.
[car horns honk]
[Heidi laughs]
You're looking at me like...
[chokes]
I'm trying not to
self-defeat at the moment.
You-- don't, don't.
Don't, don't, don't.
You just need to redirect.
-You have very pretty fabric.
-Yeah.
You have very pretty colors.
Don't overthink it.
Just go with your gut.
What, do you have goldfish
on your socks?
[chuckling]:
I do. My mom gave 'em to me.
See? You have your
lucky goldfish socks on.
-You can do this.
-Yes.
[laughing]:
Thank you.
Hi, Kentaro.
KENTARO: So, I was inspired
by this color.
-The print is so pretty.
-Yeah.
But I think I'm, like, very OCD.
If, like, little things goes
wrong, like, I don't feel
like I don't want
to make this anymore.
HEIDI:
Right.
No, because it's nice
when it oozes out a little bit.
-HEIDI: Ooh...
-AARON: Okay.
-Good "ooh," yes?
-TIM: And that's a good "ooh."
-That is a good "ooh."
-AARON: Perfect.
I saw this weird
little vent, um...
-TIM: Art deco.
-AARON: Yeah. And I looked...
HEIDI:
That's very pretty.
Yeah, I loved how shiny it was,
-and kind of the textural
aspect. -HEIDI: Mm-hmm.
And I kind of like the print.
So, will you do this
all over, or...
I have this design
that's kind of like a... a top
and then a little short.
I was thinking if I had
enough time, I was gonna do
a quick little wrap kimono
or wrap dress,
but I know that's
a little ambitious on this one.
-Be ambitious.
-Yes. -Okay.
I'm super selfish.
I want the best look.
-Yay. That makes me happy.
-I think this is a great start.
-Okay.
-TIM: Thank you, Aaron.
HEIDI:
I think a lot of you are really
on the right path already.
Do you guys feel confident?
-Yeah. -More.
-TIM: All right.
Good luck.
See you on the runway.
-Bye, everybody.
-Thank you. Night, night. -Bye.
TIM: And your models will be in
in two and a half hours.
All right, we'll see you later.
-Bye, guys.
-Thank you.
♪ ♪
MICHAEL: I've never had
the funds or the resources
to be able to reproduce
my garments,
so winning this challenge
is really important
because, as a designer,
that's ultimately what
you want.
You want people
to wear your pieces.
If I help you, will you
sew my pant seams?
Yes. I just need help
figuring out
-what it should look like.
-SHAWN: The print or what?
Well, the print is-- I don't
even know what at this point.
MARGARITA: I mean, we all help
each other out in the workroom,
which is not ill*gal,
but I think, for the twins,
they take it to a whole
different level.
It's not fair.
AARON:
How's sewing with the silk?
-Has everyone been doing well
with it? -CLAIRE: It's okay.
-KENYA: No.
-CLAIRE: It's not easy.
-SAMANTHA: Worst fabric ever.
-KENYA: Freaking sucks.
Damn, everyone had a moment.
♪ ♪
SAMANTHA:
Hey, girls.
-How are you?
-Hi, sweetie.
So let's try on
these shorts first.
Let me tie this really quickly.
KENYA:
My model is beautiful.
I've actually been
looking forward
to, uh, working with her,
but I'm not in a good place
for her to try anything on.
I've got to get busy. I got to,
I got to make you happy.
Too baggy?
You want to look like that?
Mm-hmm.
I love Kentaro's design.
I did give him a little advice.
In my industry, I'm known
for my shape.
I'm known as the Naomi of plus.
And no one is showing it.
Okay.
Let's go, Kentaro.
Let's try this on.
I am liking the way this teal
is looking on the silver.
-This is beautiful on your skin.
-JAZZMINE: Oh, this feels good.
-Does it?
-Yeah. It feels great.
It looks good.
So I'm getting my confidence
back again.
If I can get the pants,
then I'm good.
If Deyonté is able to pull off
these joggers,
I'm confident that we'll have
a winner on our hands.
But if the joggers
are not made,
I'm definitely a bit nervous.
'Cause it might come off
a little basic.
DEYONTÉ:
I'm praying I have enough.
This looks like [bleep],
and it's my fault, it's not you.
As soon as I printed
my material,
it changed the texture of it,
so it didn't have as much flow.
And that's making me nervous
because I'm not sure
how I'm gonna finish my top.
Bye. Have a good night.
-DEYONTÉ: Bye.
-SAMANTHA: See you tomorrow.
♪ ♪
I'm definitely using this,
I'm definitely using that.
-SAMANTHA: Yeah.
-DEYONTÉ: Doggone it.
Ooh!
CLAIRE:
I don't like this.
And it's very frustrating.
-KENTARO: This challenge
is tough. -AARON: I feel you.
How are we gonna put
everything together?
-It'll be crazy.
-Wait a minute.
KENTARO:
At the end of the day,
my dress looks beautiful,
but I have no textile on it.
-BATANI: All right, guys.
It's time to go. -MICHAEL: No!
-MARGARITA: Oh, my God, one more
hour, please. -BRANDON: Come on.
-MICHAEL: Please. -KENTARO:
And knowing that I'm going
to have two hours tomorrow,
I am very nervous.
Oh, my God.
Oh, my God.
HEIDI:
Coming up on Project Runway...
Re-thread the pink machine.
MARGARITA: They're just, like,
screaming to each other,
and everyone's kind of annoyed.
SAMANTHA:
How are you feeling?
A little throw-up-ish.
I do not feel like
I'm gonna be on top.
♪ ♪
AARON:
This morning we have
two hours to finish our look.
MARGARITA: I had plans
to finish this so nicely.
And, yeah, right.
SAMANTHA:
How are you feeling?
A little throw-up-ish.
-DESIGNERS: Good morning, Tim.
-Good morning.
If anyone's in the Brother
sewing and embroidery studio,
please come in.
All right. You have two hours
this morning to send your models
to the Avon Beauty Lab
and to our hair studio.
Use the JCPenney accessory wall
carefully.
Okay, back to the sewing room.
-All right. -Okay? All right.
-Thank you, Tim.
-♪ ♪
-[sewing machine whirring]
CLAIRE: Okay, I need you
to re-thread another machine.
DEYONTÉ: Claire and Shawn are
running around like maniacs.
And I'm like,
"God, I wish I had an extra
set of hands to help me."
Shawn, I want you to tie--
um, press this top.
-This top?
-What other top?
MARGARITA: They're just, like,
screaming to each other
and that doesn't help anybody.
[bleep]
Come on.
Everyone's kind of annoyed.
-Is it this tube here?
-Yeah.
It's a tube. Okay.
CLAIRE:
Don't press it too hard.
♪ ♪
MARGARITA:
♪ Hey... ♪
♪ I'm so excited. ♪
I'm really excited, too.
Oh, they make
your butt look cute.
[laughs]
Look at that booty!
All right, give us a walk.
Oh, it's coming together.
I'm really excited to be
Ayana's model this week.
It's super natural, it's glowy,
and that's how every girl
wants to wake up.
So I think
she hit it on the nail.
Hit-- yeah,
that's the saying, right?
Hit the head on the nail?
Hit the nail on the head.
Yeah, we'll just go with that.
♪ ♪
-HECTOR: How are you?
-AYANA: How's it going?
We are doing sleepwear
for Heidi Klum's collection.
-Mm-hmm.
-So just very, very soft.
-HECTOR: We have a little bit
of blush. -Okay.
And that's going to give you
a nice highlight.
AYANA: That's beautiful,
that's just what I want.
So I was thinking,
like, rosy and maybe glossy.
-HECTOR: Let's do this one.
It's beautiful, no? -Yes.
-HECTOR: There you go.
-KENYA: Yeah.
[Kentaro grunts]
[Claire whoops]
AMY:
Okay.
-I'm happy.
-Good.
-Yeah.
-It's all done.
Thank you.
[laughs]
You're gonna rock this one.
DEYONTÉ: The skirt
is looking really good.
I feel like all I have to do
is add an elastic waistband.
-DEYONTÉ: I love it.
-Okay. All right.
DEYONTÉ:
Okay.
The look's a little older
for me.
I do, once again,
feel a little frumpy.
I'm fully covered.
I'm just missing the sexy.
-Oh, hi, Tim.
-TIM: Designers,
in ten minutes,
you and your models and I
are going down to the runway,
all right?
-ALL: All right.
-TIM: Ten minutes, everyone.
-Thank you.
-SAMANTHA: Thank you.
♪ ♪
-SHAWN: Better?
-Yes?
Print on the hem,
print on the sash, no sash?
-I like the sash.
-You like it?
I've done
so many sashes, though.
CLAIRE:
I like the sash.
I think Shawn's look is nice.
It looks elegant.
The twins tag team,
so I guess it's 50% hers,
KENYA:
Let me see.
Turn around, see your butt.
I'm actually concerned
about Kenya.
She has produced so many
strong looks so far,
but that look is definitely
gonna be in the bottom.
♪ ♪
KENTARO:
Oh, my gosh, I'm tired.
Ha. I know you are; we are, too.
LIRIS:
I think the look is beautiful.
The fit, I love. I love
because it shows my curves.
He gets an A+ from me.
All right, designers and models,
we're going down to the runway.
Follow me, everybody.
-Off we go.
-[sighs]
SAMANTHA:
It is what it is.
Kenya.
KENYA:
I do not feel
like I'm gonna be on top.
I got sewing issues,
threads that are hanging.
There is going to be
some choice words
for me from Zac, Heidi and Nina.
Hello.
-DESIGNERS: Hello.
-Hi.
Welcome to the runway.
As you know in fashion,
one day you're in,
and the next day, you're out.
There are 13 of you here, and
after tonight, there will be 12.
Tim and I sent you to the top
of the Empire State Building
for a very special,
once in a lifetime sleepover.
For this challenge, we asked
you to create a sleepwear look
for my Heidi Klum Intimates
sleepwear line.
You had the fabric
and the supplies,
and one day to put
your look together.
As you know, the winner
of today's challenge
will have their look
reproduced and sold
as part of my line.
All right, let's say hello
to our judges.
First, we have creative director
for Brooks Brothers Women
and fashion designer Zac Posen.
-DESIGNERS: Hi, Zac.
-Hi, designers.
Creative director for Marie
Claire magazine Nina Garcia.
-DESIGNERS: Hi, Nina.
-Hello, designers.
And actress, singer and designer
of her own capsule collection
for Fabletics, Demi Lovato.
-Thank you for being here today.
-Hi, Demi. -Hello.
Also, we love to have Tim Gunn
here for the runway show,
and as you know,
he's your mentor,
and will not be judging
your looks.
All right, let's start the show.
♪ ♪
AMY:
When I look at my garment,
it is graceful, it's elegant,
the color is stunning
on Sanita.
I'm pleased
with my look overall.
BRANDON: Meisha's strutting it,
you know,
she was so happy with it.
She looks effortless, and
she looks, she looks beautiful.
MARGARITA: When Colleen walks
out on the runway,
she's gliding, she looks
fabulous, she looks ethereal.
She's feeling
very sexy and comfortable,
you can see it on her face,
she's just, like, floating.
CLAIRE: My design
has an easy attitude to it.
I like making simple things
out of bright colors
with really good construction,
and I think
that's what I showed them.
BATANI: I really like
the flow of my dress.
My design is very angelic
and it's very peaceful,
and it's also sexy.
Heidi said you should be able
to sleep in it, so I did that.
MICHAEL: When Monique walks out
on the runway,
I am just thrilled by the way
that the bias cut
is moving on her body.
It definitely feels
very slinky,
and my concept of the 1920s
reads really well
with the overall styling.
It just looks really clean.
DEYONTÉ: Watching my look
come down the runway
feels really good.
I've created a great garment.
She looks sexy,
she's feeling it,
and she's giving us
a lot of attitude.
I feel like we might have
a shot at this.
AARON: As I'm seeing my look
come down the runway,
I'm looking at the textile
and I'm thinking
that's reading really well.
I'm just hoping that the judges
see that I took a lot of time
to make this textile.
AYANA: When I see Christina
walking down the runway,
she brings it to life,
and I'm very pleased
I was able to produce
a complete look of three pieces
that work well together.
SHAWN: I'm watching Janine come
down the runway, and literally,
the first thought is,
"Wow! Look at her butt.
Look at how stunning
the charmeuse of those pants,"
the fabric is shimmering.
This is something I'm proud of.
KENYA: As my look is coming down
the runway, I'm feeling okay.
I know that there are
some construction issues,
and some sewing problems, but
the silhouette is beautiful.
So hopefully, I'll be safe.
KENTARO:
Seeing my garment,
it looks good,
it looks beautiful.
Had a lot of hot,
beautiful movement.
I really like it.
SAMANTHA: I'm watching my look
come down the runway,
and I'm thinking, "I actually
really love the pants.
I think they turned out
flawlessly.
It's simple but elegant,
and I am so proud.
If I call your name,
please step forward.
Aaron.
Kentaro.
Michael.
Deyonté. Shawn.
Kenya.
If I have not called your name,
congratulations,
your scores have qualified you
to move onto the next round.
You can leave the runway.
Thank you.
The six of you have the highest
and the lowest scores.
One of you will be named
the winner,
and one of you will be out.
HEIDI:
Michael, tell us about your look
and your inspiration.
When we spent the night
at the Empire State Building,
I was instantly inspired
by the art deco,
so I wanted to do
that mirror image
of graphic lines
throughout the body
that complemented her shape.
First of all, I love
the color combination.
The blush is so pretty,
you know,
it'll complement
many skin tones.
It's practical,
it's comfortable,
and it's something
that I would sleep in.
Thank you.
It looks sophisticated,
sexy, expensive.
There's some design here.
I love that effect in the back.
The multi-straps.
The art deco motif.
It almost looks like the top
of the Chrysler Building.
There's a sensuality to her,
and a sophistication to her.
It feels very 1920s,
very New York.
Yeah, it's really beautiful.
Congratulations.
Thank you.
-Aaron. -I was inspired
by one of the vents
as we were walking by, it had
this really cool staggered,
like, half-repeat print.
So I made like a stamp
kind of block,
and then I, like,
made a print on there.
I would love to know
what happened.
I was really loving the print
that you were making.
It's just what you did with it,
I'm so surprised.
This is something that is going
into the real world.
You're giving
whoever she is out there
two pieces
that are way too tight,
that are strangling on top,
it's too high.
Who wants to wear that?
Aaron, thank goodness
you're wearing underpants.
HEIDI:
It's a little distracting, yeah?
ZAC:
It's a little distracting.
When you're presenting
a model next to you,
just remember that you want
that to be highlighted.
Definitely, definitely.
As for the look, I kind of
thought it was lackluster.
You got to bring it up, this is
Runway, the world is watching,
and it needs to be
a stronger point of view.
-HEIDI: Shawn.
-So when I first walked
into the Empire State Building,
I noticed the plaque
of its origin,
that suggested the building
was sleek and slender,
and I was thinking that I want
to evoke the same kind
of feeling in my outfit.
I have to say, I was
a little worried yesterday...
...but you really pulled it
together.
You gave us something
sophisticated, sexy, elegant.
Here, you have
a beautiful jumpsuit
that you can wear to bed,
you can put that
on a pair of heels,
a nice little leather jacket,
and you have a two-in-one,
you can go out in that.
-Pajama glamour.
-HEIDI: Pajama glamour.
DEMI: It really pops to me
because it is so tailored.
You definitely nailed it
with the Empire State Building
inspiration,
how it's tall and slender
and it's beautiful.
-Thank you very much.
-Deyonté.
So, after my critique
with you and Tim,
I did some revamping.
And so I did a freehand
dye technique on this gown.
I think it feels good.
It looks dreamy
and she looks great in it.
NINA:
First of all, it doesn't even
look like something
to sleep or lounge in.
It looks like a dress.
The color, the green takes over,
and it feels like
you're just wearing
some hospital gown.
-ZAC: It's boring.
-NINA: It's boring.
This didn't do it for me today.
-Again. Ugh.
-I'm sorry.
Where is this sexy to you? Show
me. What is sexy about this?
Well, when she releases it
or takes it out and she
-takes this off. -Then it
becomes sexy? Let's have a look.
Let's take it out. Let's see
if it becomes sexy now.
ZAC:
No.
-HEIDI: Do you not...?
-ZAC: No, no, no, no, no.
You have to give us
something sexy, you know?
A woman wants
to feel comfortable
but sexy at the same time.
And I want people
to buy it, too.
This is going
into the real world.
Kentaro.
I saw beautiful sunrise,
and this part is like
Empire State Building.
And this opens.
-Mm.
-It's so pretty.
So, flows like a butterfly.
Will you turn around for us?
This I can see women
wanting to go to bed in.
I think you created
a really beautiful print here.
Beautiful draping.
Effortless, easy.
You know,
it has something playful,
but it's still sophisticated
and abstract.
The scalloping edge is delicate.
Impressive, ambitious.
I just thought it was a breeze
-and really nice and happy.
-Yeah.
I like happy out of you.
DEMI: I feel like this
is something
that I wouldn't mind
a significant other
seeing me in.
I have a lot of respect
for you and your piece.
-Thank you so much.
-Kenya.
Well, when we were
at the Empire State Building,
I immediately thought art.
After my critique,
I tried to take your idea
of-of going a little bit longer.
So, I gave you a robe
and I wanted
to make it backless.
I thought that that would be
kind of on the sexy side.
Let's take this piece off. Let's
have a look at this romper.
How are you getting in
and out of this romper?
ZAC:
That's just cuter.
-HEIDI: Let's have a look.
-KENYA: Well, the hook-and-eye
-broke and... -HEIDI: So, it's
in the middle of the night...
-Uh-huh. -...you really are
busting to go to the toilet,
you have to fiddle around
with this hook-and-eye
getting out of this thing.
I would've peed
in my pants already.
[Zac laughs]
HEIDI:
This is sleepwear, you guys.
You have to be able to get
in and out of this thing.
I have to say, Kenya, I'm really
sad to see you at the bottom
because I know what
a good designer you are
and that's not really you.
NINA: I can see that you
struggled with this,
especially since you do have
such a tailored background,
but you didn't take
the easy way out.
For that, you get
a lot of credit.
Thank you.
HEIDI: Okay, we've heard
what you had to say.
Now we're going to take
a closer look at your designs
and then I'm going to bring
you back onto the runway.
Thank you.
HEIDI: The winner
of Project Runway will receive
the opportunity to collaborate
with JCPenney
on a limited edition
capsule collection
as part
of the Project Runway line sold
at select JCPenney stores
and online at JCP.com;
a selection of Brother sewing
and embroidery machines,
with a retail value of $40,000;
makeup and beauty products
for a year, courtesy of Avon;
the new 2018 Lexus NX,
coming this fall
with advanced innovation
and safety system standard;
from the Pilot FriXion
Erasable Pen,
the official pen
of Project Runway,
a lifetime supply of pens;
an all-expense-paid luxury trip
to Japan,
including a five-star stay
near Japan's fashion center;
$100,000 to launch their line;
and the winning designer
and model will receive
a fashion spread
in Marie Claire magazine.
-HEIDI: Hi, Tim.
-Hi.
I'm not sure if we want to see
a lot of them close-up today.
TIM:
But three of them, certainly.
-Well, do you want to begin on a
positive note? -HEIDI: Yes. Yes.
TIM: We'll bring out Monique
wearing Michael.
-ZAC: And that is effortless.
-Yes.
-And incredible.
-NINA: That is beautiful.
HEIDI:
That's a beautiful gown to have.
This, I think,
is really sellable.
ZAC:
And it's producible.
It's not actually that
complicated, it's just smart.
Love it.
She's a wow.
TIM: And we have
Janine wearing Shawn.
HEIDI: Yes.
-This was so, so beautiful.
-I think it's so beautiful.
-TIM: I-I-I was stunned
that it was hers. -HEIDI: Right?
-NINA: I was stunned, too.
-ZAC: Me, too.
I love the detail on the tie
-that matches this. -NINA: A-And
touch it. -It's so simple.
-I love the shading
on the print. -NINA: Yes.
-It's really delicately done
and precise. -NINA: Yes.
No, I'm impressed with her
this week.
TIM:
Liris is wearing Kentaro.
HEIDI: I think this
is a beautiful nightgown.
Now, I just have to say--
now-now we're gonna
go technical--
it's pretty incredible...
-HEIDI: It's incredible. -ZAC:
...to do this kind of technique.
HEIDI: He said he did it
with the tweezers.
-He said with tweezers.
-You have to to pull it out
-and turn it, I mean...
-Really? -HEIDI: Yes.
-It's pretty serious to do that
in that timing. -Wow.
-Pretty. -I can totally see
women falling in love with that.
-Mm-hmm.
-You know?
I just love how delicate
the top is.
I'm glad we see color from him.
I think it's fun.
I-I-I liked it.
NINA:
This could be a real winner.
TIM: And we have Samantha
wearing Aaron.
-HEIDI: Not loving that so much.
-[Nina groans]
This feels crooked.
-This feels inexpensive.
-HEIDI: Oh, this is a...
-You don't want that.
-No.
We don't need to go further.
It's not finished.
There's no back to this.
It's a tucked-in piece
of fabric.
HEIDI:
It's just a front flap?
-ZAC: Yup.
-NINA: What do you mean?
HEIDI:
It is just a front flap.
-NINA: Oh, well.
-ZAC: Too bad.
-Bad.
-It's bad.
And we have Jazzmine
wearing Deyonté.
[Heidi groans]
I mean, it's just...
-High armhole again.
-HEIDI: There's no design here
-as far as I'm concerned.
-There's no design,
and this is, like,
the second time we've had this.
I'm uninspired.
Maybe with more time, the ideas
are able to come together.
I'm just not seeing it.
Sometimes you don't get
the luxury of time, though.
TIM:
And Yordanos is wearing Kenya.
DEMI: I think this was
my least favorite.
I don't understand what's
happening with the neckline.
HEIDI: I don't understand
what's happening anywhere.
-ZAC: It's just... -NINA: It's
a little complicated.
-ZAC: It's complicated. -HEIDI:
It is way too complicated.
But I-I'd rather see complicated
than nothing.
-Than nothing.
-Right?
At least she had
an attempt to design
with a drawstring as opposed to
the pull-on elastic waistband.
I mean, we can't even talk
about how this is constructed.
-Like, it's... beyond.
-No.
All right,
we've made our decision.
Let's bring them back out.
Designers, the six of you
had the highest
and the lowest scores.
One of you will be named
the winner
and one of you will be out.
Michael, you are the winner
of this challenge.
Thank you.
Your look will be
reproduced and sold
with my Heidi Klum
Intimates line.
-So, congratulations.
-[laughs]
-I'm very excited about it.
-MICHAEL: Thank you so much.
I'm just really happy
that my work is recognized,
so thank you.
You're in.
You can leave the runway.
Thank you so much.
I have been safe
this whole time,
and to finally win...
[chuckles] ...straight up,
I-I-I'm, like, still in shock.
[designers cheer and laugh]
Oh, my God, that's awesome.
Congratulations.
Congratulations,
congratulations.
Seriously, seriously.
I'm still, like, shaking.
-Fantastic.
-I'm so proud.
So, you're gonna be
in production.
-I know.
-That's insane.
-It really means a lot, yeah.
-It's a big deal. Yeah.
HEIDI:
Shawn, Kentaro, you're both in.
Great job.
You can leave the runway.
Thank you.
Kenya...
...you're in.
You can leave the runway.
Aaron,
while we really appreciated
your treatment of the fabric,
we were really underwhelmed
in what you did with it.
Deyonté, we really felt badly
for your model today.
This waistband
really was an issue.
And there was just
not enough design.
Aaron, Deyonté,
one of you will be out.
Deyonté.
I'm sorry, you're out.
Aaron, that means you're in.
You can leave the runway.
Congrats, buddy.
HEIDI:
Deyonté...
I have no doubt that
you will do great things.
Thank you, Heidi.
-I appreciate it.
-Sad to see you go.
-Mwah. Mwah.
-Auf Wiedersehen.
-Good luck to you.
-I love you guys.
-Thank you so much. All right.
-Thank you, Deyonté.
-You're gonna be a great dad,
too. -Thank you.
-Thank you. Thank you.
-Enjoy.
DEYONTÉ: Being eliminated
is the worst feeling.
Nobody wants to be
in that space.
It's so traumatic.
-KENYA: That's right.
-[vocalizes]
[designers groan]
-I'm gonna miss you guys.
-We're gonna miss you, too.
DEYONTÉ:
Oh, Tim.
TIM:
Come on over.
We are going to miss you.
And I just want to say, you,
sir, can leave on a high note.
You won the first challenge.
-I know. I feel great.
-You should.
I feel like I did what
I was supposed to do.
-Excellent.
-And I get home
[crying]: and get to see
my baby born, so...
I... things happen for a reason.
[sighs]
Told my grandma
I wasn't gonna cry.
She'll be like,
"Boy, I told you not to cry."
[laughs]
I have to send you to the
workroom to clean up your space.
-See you.
-TIM: Bye, Deyonté.
DEYONTÉ:
This Project Runway experience
has been the best experience.
My family is gonna be
super proud of me.
Where I come from,
[crying]: not many people
make it, you know?
To be chosen and, you know,
to win the first challenge,
I feel like I won
the competition.
HEIDI: Next time
on Project Runway...
TIM: Please welcome Dove Cameron
and China Anne McClain.
[cheering]
Go.
Some of you are going
to be designing a good look.
Others, an evil look.
It's heinous.
-Damn it.
-Here we go.
Beat back the costume.
She looks really
fashion-forward.
Fabric slays.
-It's like a work of art.
-Thank you.
This feels very old.
It's just ugly.
HEIDI: Visit myLifetime.com
to learn more about the fashion
you've seen on tonight's show.
Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
16x05 - We're Sleeping Wear?
Watch/Buy Amazon
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.